"""Tuple exercises"""


def hotdog_counts():
    """Return tuple of bun packs and dog packs needed for given guests."""


def swap_ends():
    """Swap the first and last items in the given list."""


def get_earliest():
    """Return earliest of two MM/DD/YYYY-formatted date strings."""


def name_key():
    """Return last-first name tuple from first-last name string."""


def sort_names():
    """Return given first-last name strings sorted by last name."""
